'use strict';

const path = require('path');
const fs = require('fs');
const core = require('@jest/core');
const loader = require('graphql-tag');

function _interopDefaultCompat (e) { return e && typeof e === 'object' && 'default' in e ? e.default : e; }

const loader__default = /*#__PURE__*/_interopDefaultCompat(loader);

function indexesOf(array, predicate) {
  const indexes = [];
  for (let i = 0; i < array.length; i++) {
    const arrayElement = array[i];
    if (predicate(arrayElement, i, array)) {
      indexes.push(i);
    }
  }
  return indexes;
}
function doImports(sourceLines, sourcePath, loadedFiles = /* @__PURE__ */ new Set()) {
  if (loadedFiles.has(sourcePath)) {
    return [];
  }
  loadedFiles.add(sourcePath);
  const indexesImportLines = indexesOf(sourceLines, (s) => /^# ?import "[^"]+"$/g.test(s));
  for (const index of indexesImportLines) {
    const relativeImportPath = sourceLines[index].split('"')[1];
    const importedFilePath = path.resolve(sourcePath, "..", relativeImportPath);
    const importedFileLines = fs.readFileSync(importedFilePath, { encoding: "utf8" }).split("\n");
    sourceLines[index] = doImports(importedFileLines, importedFilePath, loadedFiles);
  }
  return sourceLines.flat();
}
const graphqlTransformer = {
  process(sourceText, sourcePath) {
    const sourceLines = sourceText.split("\n");
    const linesWithImport = doImports(sourceLines, sourcePath);
    const foldedLines = linesWithImport.reduce((prev, curr) => `${prev}
${curr}`);
    const result = loader__default.call({ cacheable() {
    } }, foldedLines);
    const strResult = `module.exports = ${JSON.stringify(result)}`;
    const majorJestVersion = parseInt(core.getVersion().split(".")[0]);
    if (majorJestVersion >= 28) {
      return {
        code: strResult
      };
    } else {
      return strResult;
    }
  }
};

module.exports = graphqlTransformer;
